@@ -28,7 +28,7 @@ import binascii
 import struct
 import itertools
 
-from Cryptodome.Util.py3compat import *
+from Cryptodome.Util.py3compat import bchr, bord, tobytes, tostr, iter_range
 
 from Cryptodome import Random
 from Cryptodome.IO import PKCS8, PEM
@@ -125,7 +125,7 @@ class DsaKey(object):
 
         r = pow(g, k, p) % q  # r = (g**k mod p) mod q
         s = (inv_blind_k * (blind_factor * m + blind_x * r)) % q
-        return list(map(int, (r, s)))
+        return map(int, (r, s))
 
     def _verify(self, m, sig):
         r, s = sig
@@ -184,7 +184,7 @@ class DsaKey(object):
             tuple : (p,q,g)
         """
 
-        return list(map(int, [self._key[comp] for comp in ('p', 'q', 'g')]))
+        return [int(self._key[comp]) for comp in ('p', 'q', 'g')]
 
     def __repr__(self):
         attrs = []
@@ -204,7 +204,7 @@ class DsaKey(object):
         except KeyError:
             raise AttributeError(item)
 
-    def exportKey(self, format='PEM', pkcs8=None, passphrase=None,
+    def export_key(self, format='PEM', pkcs8=None, passphrase=None,
                   protection=None, randfunc=None):
         """Export this DSA key.
 
@@ -278,12 +278,12 @@ class DsaKey(object):
                 else:
                     return x
 
-            tup2 = list(map(func, tup1))
-            keyparts = [b('ssh-dss')] + tup2
-            keystring = b('').join(
+            tup2 = [func(x) for x in tup1]
+            keyparts = [b'ssh-dss'] + tup2
+            keystring = b''.join(
                             [struct.pack(">I", len(kp)) + kp for kp in keyparts]
                             )
-            return b('ssh-dss ') + binascii.b2a_base64(keystring)[:-1]
+            return b'ssh-dss ' + binascii.b2a_base64(keystring)[:-1]
 
         # DER format is always used, even in case of PEM, which simply
         # encodes it into BASE64.
@@ -329,6 +329,9 @@ class DsaKey(object):
             return tobytes(pem_str)
         raise ValueError("Unknown key format '%s'. Cannot export the DSA key." % format)
 
+    # Backward-compatibility
+    exportKey = export_key
+
     # Methods defined in PyCryptodome that we don't support anymore
 
     def sign(self, M, K):
@@ -379,9 +382,9 @@ def _generate_domain(L, randfunc):
     upper_bit = 1 << (L - 1)
     while True:
         V = [ SHA256.new(seed + Integer(offset + j).to_bytes()).digest()
-              for j in range(n + 1) ]
+              for j in iter_range(n + 1) ]
         V = [ Integer.from_bytes(v) for v in V ]
-        W = sum([V[i] * (1 << (i * outlen)) for i in range(n)],
+        W = sum([V[i] * (1 << (i * outlen)) for i in iter_range(n)],
                 (V[n] & ((1 << b_) - 1)) * (1 << (n * outlen)))
 
         X = Integer(W + upper_bit) # 2^{L-1} < X < 2^{L}
@@ -397,7 +400,7 @@ def _generate_domain(L, randfunc):
     # Generate g (A.2.3, index=1)
     e = (p - 1) // q
     for count in itertools.count(1):
-        U = seed + b("ggen") + bchr(1) + Integer(count).to_bytes()
+        U = seed + b"ggen" + bchr(1) + Integer(count).to_bytes()
         W = Integer.from_bytes(SHA256.new(U).digest())
         g = pow(W, e, p)
         if g != 1:
@@ -440,7 +443,7 @@ def generate(bits, randfunc=None, domain=None):
         randfunc = Random.get_random_bytes
 
     if domain:
-        p, q, g = list(map(Integer, domain))
+        p, q, g = map(Integer, domain)
 
         ## Perform consistency check on domain parameters
         # P and Q must be prime
@@ -504,7 +507,7 @@ def construct(tup, consistency_check=True):
       :class:`DsaKey` : a DSA key object
     """
 
-    key_dict = dict(list(zip(('y', 'g', 'p', 'q', 'x'), list(map(Integer, tup)))))
+    key_dict = dict(zip(('y', 'g', 'p', 'q', 'x'), map(Integer, tup)))
     key = DsaKey(key_dict)
 
     fmt_error = False
@@ -638,22 +641,22 @@ def import_key(extern_key, passphrase=None):
     if passphrase is not None:
         passphrase = tobytes(passphrase)
 
-    if extern_key.startswith(b('-----')):
+    if extern_key.startswith(b'-----'):
         # This is probably a PEM encoded key
         (der, marker, enc_flag) = PEM.decode(tostr(extern_key), passphrase)
         if enc_flag:
             passphrase = None
         return _import_key_der(der, passphrase, None)
 
-    if extern_key.startswith(b('ssh-dss ')):
+    if extern_key.startswith(b'ssh-dss '):
         # This is probably a public OpenSSH key
-        keystring = binascii.a2b_base64(extern_key.split(b(' '))[1])
+        keystring = binascii.a2b_base64(extern_key.split(b' ')[1])
         keyparts = []
         while len(keystring) > 4:
             length = struct.unpack(">I", keystring[:4])[0]
             keyparts.append(keystring[4:4 + length])
             keystring = keystring[4 + length:]
-        if keyparts[0] == b("ssh-dss"):
+        if keyparts[0] == b"ssh-dss":
             tup = [Integer.from_bytes(keyparts[x]) for x in (4, 3, 1, 2)]
             return construct(tup)
 
